==> aws-cdk-scala_3-0.5.1-sources.jar: io/burkard/cdk/services/batch/cfnJobDefinition/ContainerPropertiesProperty.scala <==
package io.burkard.cdk.services.batch.cfnJobDefinition

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object ContainerPropertiesProperty {

  def apply(
    image: String,
    ulimits: Option[List[_]] = None,
    mountPoints: Option[List[_]] = None,
    vcpus: Option[Number] = None,
    secrets: Option[List[_]] = None,
    networkConfiguration: Option[software.amazon.awscdk.services.batch.CfnJobDefinition.NetworkConfigurationProperty] = None,
    readonlyRootFilesystem: Option[Boolean] = None,
    command: Option[List[String]] = None,
    instanceType: Option[String] = None,
    volumes: Option[List[_]] = None,
    linuxParameters: Option[software.amazon.awscdk.services.batch.CfnJobDefinition.LinuxParametersProperty] = None,
    executionRoleArn: Option[String] = None,
    environment: Option[List[_]] = None,
    resourceRequirements: Option[List[_]] = None,
    privileged: Option[Boolean] = None,
    logConfiguration: Option[software.amazon.awscdk.services.batch.CfnJobDefinition.LogConfigurationProperty] = None,
    jobRoleArn: Option[String] = None,
    fargatePlatformConfiguration: Option[software.amazon.awscdk.services.batch.CfnJobDefinition.FargatePlatformConfigurationProperty] = None,
    user: Option[String] = None,
    memory: Option[Number] = None
  ): software.amazon.awscdk.services.batch.CfnJobDefinition.ContainerPropertiesProperty =
    (new software.amazon.awscdk.services.batch.CfnJobDefinition.ContainerPropertiesProperty.Builder)
      .image(image)
      .ulimits(ulimits.map(_.asJava).orNull)
      .mountPoints(mountPoints.map(_.asJava).orNull)
      .vcpus(vcpus.orNull)
      .secrets(secrets.map(_.asJava).orNull)
      .networkConfiguration(networkConfiguration.orNull)
      .readonlyRootFilesystem(readonlyRootFilesystem.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .command(command.map(_.asJava).orNull)
      .instanceType(instanceType.orNull)
      .volumes(volumes.map(_.asJava).orNull)
      .linuxParameters(linuxParameters.orNull)
      .executionRoleArn(executionRoleArn.orNull)
      .environment(environment.map(_.asJava).orNull)
      .resourceRequirements(resourceRequirements.map(_.asJava).orNull)
      .privileged(privileged.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .logConfiguration(logConfiguration.orNull)
      .jobRoleArn(jobRoleArn.orNull)
      .fargatePlatformConfiguration(fargatePlatformConfiguration.orNull)
      .user(user.orNull)
      .memory(memory.orNull)
      .build()
}

==> aws-cdk-scala_3-0.16.0-sources.jar: io/burkard/cdk/services/batch/cfnJobDefinition/ContainerPropertiesProperty.scala <==
package io.burkard.cdk.services.batch.cfnJobDefinition

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object ContainerPropertiesProperty {

  def apply(
    image: String,
    ulimits: Option[List[_]] = None,
    mountPoints: Option[List[_]] = None,
    vcpus: Option[Number] = None,
    secrets: Option[List[_]] = None,
    networkConfiguration: Option[software.amazon.awscdk.services.batch.CfnJobDefinition.NetworkConfigurationProperty] = None,
    readonlyRootFilesystem: Option[Boolean] = None,
    command: Option[List[String]] = None,
    instanceType: Option[String] = None,
    volumes: Option[List[_]] = None,
    linuxParameters: Option[software.amazon.awscdk.services.batch.CfnJobDefinition.LinuxParametersProperty] = None,
    executionRoleArn: Option[String] = None,
    environment: Option[List[_]] = None,
    resourceRequirements: Option[List[_]] = None,
    privileged: Option[Boolean] = None,
    logConfiguration: Option[software.amazon.awscdk.services.batch.CfnJobDefinition.LogConfigurationProperty] = None,
    jobRoleArn: Option[String] = None,
    fargatePlatformConfiguration: Option[software.amazon.awscdk.services.batch.CfnJobDefinition.FargatePlatformConfigurationProperty] = None,
    user: Option[String] = None,
    memory: Option[Number] = None
  ): software.amazon.awscdk.services.batch.CfnJobDefinition.ContainerPropertiesProperty =
    (new software.amazon.awscdk.services.batch.CfnJobDefinition.ContainerPropertiesProperty.Builder)
      .image(image)
      .ulimits(ulimits.map(_.asJava).orNull)
      .mountPoints(mountPoints.map(_.asJava).orNull)
      .vcpus(vcpus.orNull)
      .secrets(secrets.map(_.asJava).orNull)
      .networkConfiguration(networkConfiguration.orNull)
      .readonlyRootFilesystem(readonlyRootFilesystem.map(Boolean.box).orNull)
      .command(command.map(_.asJava).orNull)
      .instanceType(instanceType.orNull)
      .volumes(volumes.map(_.asJava).orNull)
      .linuxParameters(linuxParameters.orNull)
      .executionRoleArn(executionRoleArn.orNull)
      .environment(environment.map(_.asJava).orNull)
      .resourceRequirements(resourceRequirements.map(_.asJava).orNull)
      .privileged(privileged.map(Boolean.box).orNull)
      .logConfiguration(logConfiguration.orNull)
      .jobRoleArn(jobRoleArn.orNull)
      .fargatePlatformConfiguration(fargatePlatformConfiguration.orNull)
      .user(user.orNull)
      .memory(memory.orNull)
      .build()
}
